summaryrefslogtreecommitdiff
path: root/include/internal/routine.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/internal/routine.h')
-rw-r--r--include/internal/routine.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/include/internal/routine.h b/include/internal/routine.h
index f2f236ac..6df186c5 100644
--- a/include/internal/routine.h
+++ b/include/internal/routine.h
@@ -62,13 +62,17 @@ class Routine {
StatusCode TestMatrixAP(const size_t n, const Buffer<T> &buffer,
const size_t offset, const size_t data_size);
// Tests for valid inputs of vectors X and Y
StatusCode TestVectorX(const size_t n, const Buffer<T> &buffer, const size_t offset,
const size_t inc, const size_t data_size);
StatusCode TestVectorY(const size_t n, const Buffer<T> &buffer, const size_t offset,
const size_t inc, const size_t data_size);
+
+ // Tests for valid inputs of other vectors
StatusCode TestVectorDot(const size_t n, const Buffer<T> &buffer, const size_t offset,
const size_t data_size);
+ StatusCode TestVectorIndex(const size_t n, const Buffer<unsigned int> &buffer,
+ const size_t offset, const size_t data_size);
// Copies/transposes a matrix and padds/unpads it with zeroes. This method is also able to write
// to symmetric and triangular matrices through optional arguments.
@@ -62,13 +62,17 @@ class Routine {
StatusCode TestMatrixAP(const size_t n, const Buffer<T> &buffer,
const size_t offset, const size_t data_size);
- // Tests for valid inputs of vectors X and Y
+ // Tests for valid inputs of vector X and Y
StatusCode TestVectorX(const size_t n, const Buffer<T> &buffer, const size_t offset,
const size_t inc, const size_t data_size);